@@ -23,7 +23,9 @@
 #define WINPR_HAVE_GETPWUID_R
 #define WINPR_HAVE_STRNDUP
 #define WINPR_HAVE_UNWIND_H
-/* #undef WINPR_WITH_PNG */
+#define WINPR_WITH_PNG
+
+/* #undef WINPR_HAVE_STRERROR_R */
 
 #define WITH_EVENTFD_READ_WRITE
 
@@ -32,9 +34,15 @@
 /* #undef WITH_INTERNAL_MD4 */
 /* #undef WITH_INTERNAL_MD5 */
 
+#define WITH_WINPR_JSON
+
 /* #undef WITH_DEBUG_NTLM */
 /* #undef WITH_DEBUG_THREADS */
 /* #undef WITH_DEBUG_EVENTS */
 /* #undef WITH_DEBUG_MUTEX */
 
+#define WINPR_UTILS_IMAGE_WEBP
+#define WINPR_UTILS_IMAGE_PNG
+#define WINPR_UTILS_IMAGE_JPEG
+
 #endif /* WINPR_CONFIG_H */
